@@ -10,4 +10,7 @@ system("id");
 my ($uid, $gid) = drop_privileges($user) or die "Could not drop privileges";
 print "Current UID is $uid, GID is $gid\n";
 system("id");
+if(-f "/proc/$$/status") {
+    system("cat /proc/$$/status");
+}
 
